@@ -14,3 +14,7 @@ LACEWORK_SUBACCOUNT_ENVIRONMENT_VARIABLE = "LW_SUBACCOUNT"
 LACEWORK_API_KEY_ENVIRONMENT_VARIABLE = "LW_API_KEY"
 LACEWORK_API_SECRET_ENVIRONMENT_VARIABLE = "LW_API_SECRET"
 LACEWORK_API_BASE_DOMAIN_ENVIRONMENT_VARIABLE = "LW_BASE_DOMAIN"
+LACEWORK_API_CONFIG_SECTION_ENVIRONMENT_VARIABLE = "LW_PROFILE"
+
+# Config file paths.
+LACEWORK_CLI_CONFIG_RELATIVE_PATH = ".lacework.toml"
